@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2008-2015 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2008-2019 Jakub Wilk <jwilk@jwilk.net>
 #
 # This file is part of djvusmooth.
 #
@@ -19,15 +19,6 @@ Checks for djvusmooth dependencies.
 
 djvulibre_path = None
 
-def _check_signals():
-    # Protect from scanadf and possibly other software that sets SIGCHLD to
-    # SIG_IGN.
-    # https://bugs.debian.org/596232
-    import os
-    import signal
-    if os.name == 'posix':
-        signal.signal(signal.SIGCHLD, signal.SIG_DFL)
-
 def _check_djvu():
     # On Windows, special measures may be needed to find the DjVuLibre DLL.
     global djvulibre_path
@@ -40,14 +31,14 @@ def _check_djvu():
     try:
         import djvu.decode
     except ImportError as exc:
-        raise ImportError('{exc}; perhaps python-djvulibre is not installed'.format(exc=exc))
+        raise ImportError('{exc}; is python-djvulibre installed?'.format(exc=exc))
     del djvu  # quieten pyflakes
 
 def _check_wx():
     try:
         import wxversion
     except ImportError as exc:
-        raise ImportError('{exc}; perhaps wxPython is not installed'.format(exc=exc))
+        raise ImportError('{exc}; is wxPython installed?'.format(exc=exc))
     for ver in ['2.8-unicode', '3.0']:
         try:
             wxversion.select(ver, optionsRequired=True)
@@ -58,7 +49,6 @@ def _check_wx():
     else:
         raise ImportError('wxPython 3.0 or 2.8 in Unicode mode is required')
 
-_check_signals()
 _check_djvu()
 _check_wx()
 
