@@ -1,6 +1,6 @@
 # encoding=UTF-8
 
-# Copyright © 2008-2015 Jakub Wilk <jwilk@jwilk.net>
+# Copyright © 2008-2019 Jakub Wilk <jwilk@jwilk.net>
 # Copyright © 2009 Mateusz Turcza <mturcza@mimuw.edu.pl>
 #
 # This file is part of djvusmooth.
@@ -22,7 +22,7 @@ import os.path
 import threading
 from Queue import Queue, Empty as QueueEmpty
 
-import djvusmooth.dependencies as __dependencies
+import djvusmooth.dependencies
 
 import wx
 import wx.lib.ogl
@@ -810,7 +810,8 @@ class MainWindow(wx.Frame):
                 pass
             else:
                 exception = None
-            wx.CallAfter(lambda: self.after_external_edit_outline(new_repr, disabler, exception))
+            wx.CallAfter(self.after_external_edit_outline, new_repr, disabler, exception)
+            disabler = exception = None
         disabler = wx.WindowDisabler()
         thread = threading.Thread(target=job, args=(disabler,))
         thread.start()
@@ -849,7 +850,8 @@ class MainWindow(wx.Frame):
                 pass
             else:
                 exception = None
-            wx.CallAfter(lambda: self.after_external_edit_text(new_sexpr, disabler, exception))
+            wx.CallAfter(self.after_external_edit_text, new_sexpr, disabler, exception)
+            disabler = exception = None
         disabler = wx.WindowDisabler()
         thread = threading.Thread(target=job, args=(disabler,))
         thread.start()
